@@ -6,7 +6,7 @@ use utf8;
 package Marlin;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.012000';
+our $VERSION   = '0.012001';
 
 use constant _ATTRS => qw( caller this parents roles attributes strict constructor modifiers inhaled_from short_name is_struct plugins setup_steps_with_plugins delayed );
 use B::Hooks::AtRuntime   ();
@@ -93,7 +93,8 @@ sub try_inhale {
 	
 	# Inhale Class::XSConstructor
 	if ( $INC{'Class/XSConstructor.pm'} and my $xscon_meta = do {
-		Class::XSConstructor::get_metadata($k);
+		my $m = Class::XSConstructor::get_metadata($k);
+		$m && defined $m->{package} ? $m : undef;
 	} ) {
 		my @attrs = map {
 			my $attr = $_;
